==> vradi-swing-0.1.0-sources.jar: com/jurismarches/vradi/ui/offer/OfferListColumnFactory.java <==
/*
 * *##%
 * Vradi :: Swing
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */
package com.jurismarches.vradi.ui.offer;

import static org.nuiton.i18n.I18n._;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jdesktop.swingx.JXTable;
import org.jdesktop.swingx.table.ColumnFactory;
import org.jdesktop.swingx.table.TableColumnExt;

import com.jurismarches.vradi.VradiHelper;
import com.jurismarches.vradi.entities.Form;
import com.jurismarches.vradi.entities.Infogene;
import com.jurismarches.vradi.entities.InfogeneImpl;

/**
 * <code>OfferListColumnFactory</code> restore the visibility state of
 * <code>Infogene</code> colums.
 *
 * OfferListColumnFactory is used by OfferListColumnFactory and
 * OfferListUI.jaxx.
 * 
 * @author $Author: sletellier $
 * @version $Revision: 1199 $ $Date: 2010-08-13 19:50:12 +0200 (ven., 13 août 2010) $
 * @since 0.0.4
 */
public class OfferListColumnFactory extends ColumnFactory {
    private static final long serialVersionUID = 1L;
    private static final Log log = LogFactory.getLog(OfferListColumnFactory.class);
    private static final String I18N_COLUMN_PREFIX = "vradi.offer.";
    
    private final List<TableColumnExt> columnExts = new ArrayList<TableColumnExt>();
    
    public OfferListColumnFactory() {
        initAvailableColumns();
    }
    
    @Override
    public TableColumnExt createTableColumn(int modelIndex) {
        TableColumnExt columnExt = new TableColumnExt(columnExts.get(modelIndex));
        return columnExt;
    }
    
    @Override
    public void packColumn(JXTable table, TableColumnExt columnExt, int margin,
            int max) {
        int preferredWidth = columnExt.getPreferredWidth();
        if (preferredWidth < 400) {
            super.packColumn(table, columnExt, margin, 400);
        } else {
            // consider the column has been manually resized
        }
    }
    
    protected void initAvailableColumns() {
        List<String> vradiListColumns = VradiHelper.getVradiListColumns();
        boolean empty = vradiListColumns.isEmpty();

        // la liste des colonnes contient tout les champs de l'infogene
        List<String> fieldNames = new ArrayList<String>();
        for(String fieldName : InfogeneImpl.extensionInfogene.getFieldNames()) {
            fieldNames.add(Infogene.EXT_INFOGENE + "." + fieldName);
        }
        // plus datePeremption, datePub, xmlStreamURL
        fieldNames.add(Form.FQ_FIELD_FORM_DATEPUB);
        fieldNames.add(Form.FQ_FIELD_FORM_DATEPEREMPTION);
        fieldNames.add(Form.FQ_FIELD_FORM_XMLSTREAM);

        for (String fieldName : fieldNames) {
            boolean visible = vradiListColumns.contains(fieldName);
            visible = visible || empty;

            TableColumnExt columnExt = initAvailableColumn(fieldName,
                    columnExts.size(), visible);
            columnExts.add(columnExt);
            
            if (empty) {
                // default hidden columns: id and description
                if (fieldName.equals(Infogene.FQ_FIELD_INFOGENE_ID) ||
                        fieldName.equals(Infogene.FQ_FIELD_INFOGENE_DESCRIPTION)) {
                    columnExt.setVisible(false);
                    
                } else {
                    // add fqField to vradi.columns property
                    VradiHelper.addVradiListColumns(fieldName);
                }
            }
        }
    }
    
    // Warning : Use a small i18n bug witch parse code in comment :)
    // Do not remove it : usefull for i18n.strictMode
    // _("vradi.offer.Form.datePeremption")
    // _("vradi.offer.Form.datePub")
    // _("vradi.offer.Form.xmlStreamURL")
    // _("vradi.offer.Infogene.country")
    // _("vradi.offer.Infogene.creationDate")
    // _("vradi.offer.Infogene.department")
    // _("vradi.offer.Infogene.description")
    // _("vradi.offer.Infogene.entity")
    // _("vradi.offer.Infogene.id")
    // _("vradi.offer.Infogene.objet")
    // _("vradi.offer.Infogene.sourceText")
    // _("vradi.offer.Infogene.sourceURL")
    // _("vradi.offer.Infogene.status")
    // _("vradi.offer.Infogene.tag")
    protected TableColumnExt initAvailableColumn(String fqField,
            int modelIndex, boolean visible) {
        TableColumnExt tableColumnExt = new TableColumnExt(modelIndex);
        
        tableColumnExt.setIdentifier(fqField);
        tableColumnExt.putClientProperty("fqFieldName", fqField);
        
        tableColumnExt.setEditable(false);
        tableColumnExt.setSortable(true);
        tableColumnExt.setVisible(visible);
        
        tableColumnExt.setToolTipText(_(I18N_COLUMN_PREFIX + fqField));
        
        if (log.isTraceEnabled()) {
            log.trace(String.format("adding column: %s; position: %s; visible: %s",
                    fqField, modelIndex, visible));
        }
        
        return tableColumnExt;
    }
}

==> vradi-swing-0.2.0-sources.jar: com/jurismarches/vradi/ui/offer/OfferListColumnFactory.java <==
/*
 * #%L
 * Vradi :: Swing
 * 
 * $Id: OfferListColumnFactory.java 1443 2010-09-20 08:50:49Z chatellier $
 * $HeadURL: svn+ssh://chatellier@labs.libre-entreprise.org/svnroot/vradi/vradi/tags/vradi-0.2.0/vradi-swing/src/main/java/com/jurismarches/vradi/ui/offer/OfferListColumnFactory.java $
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.ui.offer;

import static org.nuiton.i18n.I18n._;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jdesktop.swingx.JXTable;
import org.jdesktop.swingx.table.ColumnFactory;
import org.jdesktop.swingx.table.TableColumnExt;

import com.jurismarches.vradi.VradiHelper;
import com.jurismarches.vradi.entities.Form;
import com.jurismarches.vradi.entities.Infogene;
import com.jurismarches.vradi.entities.InfogeneImpl;

/**
 * <code>OfferListColumnFactory</code> restore the visibility state of
 * <code>Infogene</code> colums.
 *
 * OfferListColumnFactory is used by OfferListColumnFactory and
 * OfferListUI.jaxx.
 * 
 * @author $Author: chatellier $
 * @version $Revision: 1443 $ $Date: 2010-09-20 10:50:49 +0200 (lun., 20 sept. 2010) $
 * @since 0.0.4
 */
public class OfferListColumnFactory extends ColumnFactory {
    private static final long serialVersionUID = 1L;
    private static final Log log = LogFactory.getLog(OfferListColumnFactory.class);
    private static final String I18N_COLUMN_PREFIX = "vradi.offer.";
    
    private final List<TableColumnExt> columnExts = new ArrayList<TableColumnExt>();
    
    public OfferListColumnFactory() {
        initAvailableColumns();
    }
    
    @Override
    public TableColumnExt createTableColumn(int modelIndex) {
        TableColumnExt columnExt = new TableColumnExt(columnExts.get(modelIndex));
        return columnExt;
    }
    
    @Override
    public void packColumn(JXTable table, TableColumnExt columnExt, int margin,
            int max) {
        int preferredWidth = columnExt.getPreferredWidth();
        if (preferredWidth < 400) {
            super.packColumn(table, columnExt, margin, 400);
        } else {
            // consider the column has been manually resized
        }
    }
    
    protected void initAvailableColumns() {
        List<String> vradiListColumns = VradiHelper.getVradiListColumns();
        boolean empty = vradiListColumns.isEmpty();

        // la liste des colonnes contient tout les champs de l'infogene
        List<String> fieldNames = new ArrayList<String>();
        for(String fieldName : InfogeneImpl.extensionInfogene.getFieldNames()) {
            fieldNames.add(Infogene.EXT_INFOGENE + "." + fieldName);
        }
        // plus datePeremption, datePub, xmlStreamURL
        fieldNames.add(Form.FQ_FIELD_FORM_DATEPUB);
        fieldNames.add(Form.FQ_FIELD_FORM_DATEPEREMPTION);
        fieldNames.add(Form.FQ_FIELD_FORM_XMLSTREAM);

        for (String fieldName : fieldNames) {
            boolean visible = vradiListColumns.contains(fieldName);
            visible = visible || empty;

            TableColumnExt columnExt = initAvailableColumn(fieldName,
                    columnExts.size(), visible);
            columnExts.add(columnExt);
            
            if (empty) {
                // default hidden columns: id and description
                if (fieldName.equals(Infogene.FQ_FIELD_INFOGENE_ID) ||
                        fieldName.equals(Infogene.FQ_FIELD_INFOGENE_DESCRIPTION)) {
                    columnExt.setVisible(false);
                    
                } else {
                    // add fqField to vradi.columns property
                    VradiHelper.addVradiListColumns(fieldName);
                }
            }
        }
    }
    
    // Warning : Use a small i18n bug witch parse code in comment :)
    // Do not remove it : usefull for i18n.strictMode
    // _("vradi.offer.Form.datePeremption")
    // _("vradi.offer.Form.datePub")
    // _("vradi.offer.Form.xmlStream")
    // _("vradi.offer.Infogene.country")
    // _("vradi.offer.Infogene.creationDate")
    // _("vradi.offer.Infogene.department")
    // _("vradi.offer.Infogene.description")
    // _("vradi.offer.Infogene.entity")
    // _("vradi.offer.Infogene.id")
    // _("vradi.offer.Infogene.objet")
    // _("vradi.offer.Infogene.sourceText")
    // _("vradi.offer.Infogene.sourceURL")
    // _("vradi.offer.Infogene.status")
    // _("vradi.offer.Infogene.tag")
    protected TableColumnExt initAvailableColumn(String fqField,
            int modelIndex, boolean visible) {
        TableColumnExt tableColumnExt = new TableColumnExt(modelIndex);
        
        tableColumnExt.setIdentifier(fqField);
        tableColumnExt.putClientProperty("fqFieldName", fqField);
        
        tableColumnExt.setEditable(false);
        tableColumnExt.setSortable(true);
        tableColumnExt.setVisible(visible);
        
        tableColumnExt.setToolTipText(_(I18N_COLUMN_PREFIX + fqField));
        
        if (log.isTraceEnabled()) {
            log.trace(String.format("adding column: %s; position: %s; visible: %s",
                    fqField, modelIndex, visible));
        }
        
        return tableColumnExt;
    }
}
